# Roadmap

The [public roadmap](https://github.com/orgs/oscal-compass/projects/2) for Trestle is published as a GitHub project board.

This project serves as the up-to-date description of high-level initiatives and individual features that have been reviewed and identified as valuable to the community.

High level roadmap items are identified as `Epics`. These represent larger initiatives that need design collaboration and will result in issues representing individual features.

### Timelines

**Please take any defined dates as estimations and not strict commitments to a delivery timeline.**

We strive to release ready-to-go features monthly. This is documented through milestones. Bug and security fixes will be released on-demand.

We use 12-week iterations for high-level initiatives that must be broken down and completed. It allows the time to collect community comments, break it down into smaller issues, and schedule a monthly release.

### How to get involved

Each roadmap item is represented as a GitHub Issue. Discussions or any feedback on current roadmap items can take place in threads on the corresponding issue. To stay up to date with roadmap items, please join the OSCAL-Compass community [meetings](https://github.com/oscal-compass/community).

**Help Us Grow `compliance-trestle`!** Community contributions are essential to the project's success. To ensure we prioritize the most active and relevant issues, we're using `actions/stale` to automatically close older ones. Your participation is greatly appreciated!

#### Our Triaging Process

All new issues in `compliance-trestle` are added to the [project](https://github.com/orgs/oscal-compass/projects/2) with a status of New. All issues that need to be triaged are viewable [here](https://github.com/orgs/oscal-compass/projects/2/views/8). Once there is enough information to move forward on the issue, it can be moved to the `Backlog` by applying the `Backlog` label and moving the status to `Ready`.

### How to add an item to the roadmap?

**Contributors are encouraged to get feedback early by submitting issues to new work they would like to complete and getting feedback.**

New items on the roadmap are typically driven by changes in OSCAL and new feature requests through GitHub Issues.
During issue triage, feature requests are identified as `Epics` and added to the roadmap or individual features that can be directly added to the project `Backlog` and/or an upcoming release milestone.
